From: Greg KH <gregkh@suse.de>
To: linux-kernel@vger.kernel.org, stable@kernel.org
Cc: stable-review@kernel.org, torvalds@linux-foundation.org,
akpm@linux-foundation.org, alan@lxorguk.ukuu.org.uk,
Takashi Iwai <tiwai@suse.de>
Subject: [patch 18/71] ALSA: hda - Fix MacBookPro 3,1/4,1 quirk with ALC889A
Date: Fri, 04 Sep 2009 17:13:53 -0700 [thread overview]
Message-ID: <20090905001450.234791690@mini.kroah.org> (raw)
In-Reply-To: <20090905001824.GA18171@kroah.com>
[-- Attachment #1: alsa-hda-fix-macbookpro-3-1-4-1-quirk-with-alc889a.patch --]
[-- Type: text/plain, Size: 4070 bytes --]
2.6.30-stable review patch. If anyone has any objections, please let us know.
------------------
From: Takashi Iwai <tiwai@suse.de>
commit a3f730af7e33cea10ea66f05b2565fde1f9512df upstream.
This patch fixes the wrong headphone output routing for MacBookPro 3,1/4,1
quirk with ALC889A codec, which caused the silent headphone output.
Also, this gives the individual Headphone and Speaker volume controls.
Reference: kernel bug#14078
http://bugzilla.kernel.org/show_bug.cgi?id=14078
Signed-off-by: Takashi Iwai <tiwai@suse.de>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
---
sound/pci/hda/patch_realtek.c | 34 ++++++++++++++++++++--------------
1 file changed, 20 insertions(+), 14 deletions(-)
--- a/sound/pci/hda/patch_realtek.c
+++ b/sound/pci/hda/patch_realtek.c
@@ -6186,9 +6186,9 @@ static struct hda_verb alc885_mbp_ch2_in
};
/*
- * 6ch mode
+ * 4ch mode
*/
-static struct hda_verb alc885_mbp_ch6_init[] = {
+static struct hda_verb alc885_mbp_ch4_init[] = {
{ 0x1a, AC_VERB_SET_PIN_WIDGET_CONTROL, PIN_OUT },
{ 0x1a, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
{ 0x1a, AC_VERB_SET_CONNECT_SEL, 0x01 },
@@ -6197,9 +6197,9 @@ static struct hda_verb alc885_mbp_ch6_in
{ } /* end */
};
-static struct hda_channel_mode alc885_mbp_6ch_modes[2] = {
+static struct hda_channel_mode alc885_mbp_4ch_modes[2] = {
{ 2, alc885_mbp_ch2_init },
- { 6, alc885_mbp_ch6_init },
+ { 4, alc885_mbp_ch4_init },
};
@@ -6232,10 +6232,11 @@ static struct snd_kcontrol_new alc882_ba
};
static struct snd_kcontrol_new alc885_mbp3_mixer[] = {
- HDA_CODEC_VOLUME("Front Playback Volume", 0x0c, 0x00, HDA_OUTPUT),
- HDA_BIND_MUTE ("Front Playback Switch", 0x0c, 0x02, HDA_INPUT),
- HDA_CODEC_MUTE ("Speaker Playback Switch", 0x14, 0x00, HDA_OUTPUT),
- HDA_CODEC_VOLUME("Line-Out Playback Volume", 0x0d, 0x00, HDA_OUTPUT),
+ HDA_CODEC_VOLUME("Speaker Playback Volume", 0x0c, 0x00, HDA_OUTPUT),
+ HDA_BIND_MUTE ("Speaker Playback Switch", 0x0c, 0x02, HDA_INPUT),
+ HDA_CODEC_VOLUME("Headphone Playback Volume", 0x0e, 0x00, HDA_OUTPUT),
+ HDA_BIND_MUTE ("Headphone Playback Switch", 0x0e, 0x02, HDA_INPUT),
+ HDA_CODEC_VOLUME("Surround Playback Volume", 0x0d, 0x00, HDA_OUTPUT),
HDA_CODEC_VOLUME("Line Playback Volume", 0x0b, 0x02, HDA_INPUT),
HDA_CODEC_MUTE ("Line Playback Switch", 0x0b, 0x02, HDA_INPUT),
HDA_CODEC_VOLUME("Mic Playback Volume", 0x0b, 0x00, HDA_INPUT),
@@ -6481,14 +6482,18 @@ static struct hda_verb alc885_mbp3_init_
{0x0d, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_ZERO},
{0x0d, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(0)},
{0x0d, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(1)},
+ /* HP mixer */
+ {0x0e, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_ZERO},
+ {0x0e, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(0)},
+ {0x0e, AC_VERB_SET_AMP_GAIN_MUTE, AMP_IN_MUTE(1)},
/* Front Pin: output 0 (0x0c) */
{0x14, AC_VERB_SET_PIN_WIDGET_CONTROL, PIN_OUT},
{0x14, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
{0x14, AC_VERB_SET_CONNECT_SEL, 0x00},
/* HP Pin: output 0 (0x0d) */
{0x15, AC_VERB_SET_PIN_WIDGET_CONTROL, 0xc4},
- {0x15, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_MUTE},
- {0x15, AC_VERB_SET_CONNECT_SEL, 0x00},
+ {0x15, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
+ {0x15, AC_VERB_SET_CONNECT_SEL, 0x02},
{0x15, AC_VERB_SET_UNSOLICITED_ENABLE, ALC880_HP_EVENT | AC_USRSP_EN},
/* Mic (rear) pin: input vref at 80% */
{0x18, AC_VERB_SET_PIN_WIDGET_CONTROL, PIN_VREF80},
@@ -6885,10 +6890,11 @@ static struct alc_config_preset alc882_p
.mixers = { alc885_mbp3_mixer, alc882_chmode_mixer },
.init_verbs = { alc885_mbp3_init_verbs,
alc880_gpio1_init_verbs },
- .num_dacs = ARRAY_SIZE(alc882_dac_nids),
+ .num_dacs = 2,
.dac_nids = alc882_dac_nids,
- .channel_mode = alc885_mbp_6ch_modes,
- .num_channel_mode = ARRAY_SIZE(alc885_mbp_6ch_modes),
+ .hp_nid = 0x04,
+ .channel_mode = alc885_mbp_4ch_modes,
+ .num_channel_mode = ARRAY_SIZE(alc885_mbp_4ch_modes),
.input_mux = &alc882_capture_source,
.dig_out_nid = ALC882_DIGOUT_NID,
.dig_in_nid = ALC882_DIGIN_NID,
next prev parent reply other threads:[~2009-09-05 0:31 UTC|newest]
Thread overview: 78+ messages / expand[flat|nested] mbox.gz Atom feed top
[not found] <20090905001335.106974681@mini.kroah.org>
2009-09-05 0:18 ` [patch 00/71] 2.6.30.6-stable review Greg KH
2009-09-05 0:13 ` [patch 01/71] ehea: Fix napi list corruption on ifconfig down Greg KH
2009-09-05 0:13 ` [patch 02/71] poll/select: initialize triggered field of struct poll_wqueues Greg KH
2009-09-05 0:13 ` [patch 03/71] Make bitmask and operators return a result code Greg KH
2009-09-05 0:13 ` [patch 04/71] x86: dont send an IPI to the empty set of CPUs Greg KH
2009-09-05 0:13 ` [patch 05/71] x86: dont call ->send_IPI_mask() with an empty mask Greg KH
2009-09-05 0:13 ` [patch 06/71] mm: build_zonelists(): move clear node_load[] to __build_all_zonelists() Greg KH
2009-09-05 0:13 ` [patch 07/71] rt2x00: fix memory corruption in rf cache, add a sanity check Greg KH
2009-09-05 0:13 ` [patch 08/71] mac80211: fix panic when splicing unprepared TIDs Greg KH
2009-09-05 0:13 ` [patch 09/71] Re-introduce page mapping check in mark_buffer_dirty() Greg KH
2009-09-05 0:13 ` [patch 10/71] mm: fix hugetlb bug due to user_shm_unlock call Greg KH
2009-09-05 0:13 ` [patch 11/71] ima: hashing large files bug fix Greg KH
2009-09-05 0:13 ` [patch 12/71] kernel_read: redefine offset type Greg KH
2009-09-05 0:13 ` [patch 13/71] tracing: Fix too large stack usage in do_one_initcall() Greg KH
2009-09-05 0:13 ` [patch 14/71] sound: pcm_lib: fix unsorted list constraint handling Greg KH
2009-09-05 0:13 ` [patch 15/71] clone(): fix race between copy_process() and de_thread() Greg KH
2009-09-05 0:13 ` [patch 16/71] wmi: fix kernel panic when stack protection enabled Greg KH
2009-09-05 0:13 ` [patch 17/71] SUNRPC: Fix rpc_task_force_reencode Greg KH
2009-09-05 0:13 ` Greg KH [this message]
2009-09-05 0:13 ` [patch 19/71] KVM: take mmu_lock when updating a deleted slot Greg KH
2009-09-05 0:13 ` [patch 20/71] KVM: x86: check for cr3 validity in mmu_alloc_roots Greg KH
2009-09-05 0:13 ` [patch 21/71] KVM: MMU: protect kvm_mmu_change_mmu_pages with mmu_lock Greg KH
2009-09-05 0:13 ` [patch 22/71] KVM: MMU: do not free active mmu pages in free_mmu_pages() Greg KH
2009-09-05 0:13 ` [patch 23/71] KVM: Introduce {set/get}_interrupt_shadow() Greg KH
2009-09-05 0:13 ` [patch 24/71] KVM: Deal with interrupt shadow state for emulated instructions Greg KH
2009-09-05 0:14 ` [patch 25/71] KVM: MMU: Use different shadows when EFER.NXE changes Greg KH
2009-09-05 0:14 ` [patch 26/71] KVM: x86: Ignore reads to EVNTSEL MSRs Greg KH
2009-09-05 0:14 ` [patch 27/71] KVM: Ignore reads to K7 " Greg KH
2009-09-05 0:14 ` [patch 28/71] KVM: Fix cpuid feature misreporting Greg KH
2009-09-05 0:14 ` [patch 29/71] KVM: x86: verify MTRR/PAT validity Greg KH
2009-09-05 0:14 ` [patch 30/71] KVM: SVM: force new asid on vcpu migration Greg KH
2009-09-05 0:14 ` [patch 31/71] KVM: MMU: handle n_free_mmu_pages > n_alloc_mmu_pages in kvm_mmu_change_mmu_pages Greg KH
2009-09-05 0:14 ` [patch 32/71] [stable] [PATCH 14/16] KVM: MMU: limit rmap chain length Greg KH
2009-09-05 0:14 ` [patch 33/71] KVM: fix ack not being delivered when msi present Greg KH
2009-09-05 0:14 ` [patch 34/71] KVM: Fix KVM_GET_MSR_INDEX_LIST Greg KH
2009-09-05 0:14 ` [patch 35/71] iwl3945: fix rfkill switch Greg KH
2009-09-05 0:14 ` [patch 36/71] iwlagn: do not send key clear commands when rfkill enabled Greg KH
2009-09-05 0:14 ` [patch 37/71] libata: OCZ Vertex cant do HPA Greg KH
2009-09-05 0:14 ` [patch 38/71] SCSI: mpt2sas: Introduced check for enclosure_handle to avoid crash Greg KH
2009-09-05 0:14 ` [patch 39/71] SCSI: mpt2sas: Expander fix oops saying "Already part of another port" Greg KH
2009-09-05 0:14 ` [patch 40/71] SCSI: mpt2sas: Raid 10 Value is showing as Raid 1E in /va/log/messages Greg KH
2009-09-05 0:14 ` [patch 41/71] SCSI: mpt2sas: Excessive log info causes sas iounit page time out Greg KH
2009-09-05 0:14 ` [patch 42/71] SCSI: mpt2sas: fix infinite loop inside config request Greg KH
2009-09-05 0:14 ` [patch 43/71] SCSI: mpt2sas: fix crash due to Watchdog is active while OS in standby mode Greg KH
2009-09-05 0:14 ` [patch 44/71] SCSI: mpt2sas: fix oops because drv data points to NULL on resume from hibernate Greg KH
2009-09-05 0:14 ` [patch 45/71] [SCSI] mpt2sas: fix config request and diag reset deadlock Greg KH
2009-09-05 0:14 ` [patch 46/71] do_sigaltstack: avoid copying stack_t as a structure to user space Greg KH
2009-09-05 0:14 ` [patch 47/71] Bug Fix arch/ia64/kernel/pci-dma.c: fix recursive dma_supported() call in iommu_dma_supported() Greg KH
2009-09-05 0:14 ` [patch 48/71] x86, amd: Dont probe for extended APIC ID if APICs are disabled Greg KH
2009-09-05 0:14 ` [patch 49/71] ocfs2: Initialize the cluster were writing to in a non-sparse extend Greg KH
2009-09-05 0:14 ` [patch 50/71] ACPI processor: force throttling state when BIOS returns incorrect value Greg KH
2009-09-05 0:14 ` [patch 51/71] vfs: fix inode_init_always calling convention Greg KH
2009-09-05 0:14 ` [patch 52/71] vfs: add __destroy_inode Greg KH
2009-09-05 0:14 ` [patch 53/71] xfs: fix freeing of inodes not yet added to the inode cache Greg KH
2009-09-05 0:14 ` [patch 54/71] xfs: fix spin_is_locked assert on uni-processor builds Greg KH
2009-09-05 0:14 ` [patch 55/71] gspca - ov534: Fix ov772x Greg KH
2009-09-05 0:14 ` [patch 56/71] kthreads: fix kthread_create() vs kthread_stop() race Greg KH
2009-09-05 0:14 ` [patch 57/71] ipv6: Fix commit 63d9950b08184e6531adceb65f64b429909cc101 (ipv6: Make v4-mapped bindings consistent with IPv4) Greg KH
2009-09-05 0:14 ` [patch 58/71] USB: fix the clear_tt_buffer interface Greg KH
2009-09-05 0:14 ` [patch 59/71] USB: EHCI: use the new " Greg KH
2009-09-05 0:14 ` [patch 60/71] USB: EHCI: fix two new bugs related to Clear-TT-Buffer Greg KH
2009-09-05 0:14 ` [patch 61/71] powerpc/ps3: Add missing check for PS3 to rtc-ps3 platform device registration Greg KH
2009-09-05 0:14 ` [patch 62/71] ipv4: make ip_append_data() handle NULL routing table Greg KH
2009-09-05 0:14 ` [patch 63/71] ar9170: fix read & write outside array bounds Greg KH
2009-09-05 0:14 ` [patch 64/71] xenfb: connect to backend before registering fb Greg KH
2009-09-05 0:14 ` [patch 65/71] can: Fix raw_getname() leak Greg KH
2009-09-05 0:14 ` [patch 66/71] irda: Fix irda_getname() leak Greg KH
2009-09-05 0:14 ` [patch 67/71] appletalk: fix atalk_getname() leak Greg KH
2009-09-05 0:14 ` [patch 68/71] netrom: Fix nr_getname() leak Greg KH
2009-09-05 0:14 ` [patch 69/71] econet: Fix econet_getname() leak Greg KH
2009-09-05 0:14 ` [patch 70/71] rose: Fix rose_getname() leak Greg KH
2009-09-05 0:14 ` [patch 71/71] NET: llc, zero sockaddr_llc struct Greg KH
2009-09-05 4:54 ` [patch 00/71] 2.6.30.6-stable review Grant Coady
2009-09-05 14:48 ` Greg KH
2009-09-08 19:23 ` [Stable-review] " Luis R. Rodriguez
2009-09-09 22:44 ` Greg KH
2009-09-10 0:21 ` Luis R. Rodriguez
2009-09-10 3:00 ` Greg KH
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090905001450.234791690@mini.kroah.org \
--to=gregkh@suse.de \
--cc=akpm@linux-foundation.org \
--cc=alan@lxorguk.ukuu.org.uk \
--cc=linux-kernel@vger.kernel.org \
--cc=stable-review@kernel.org \
--cc=stable@kernel.org \
--cc=tiwai@suse.de \
--cc=torvalds@linux-foundation.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -6481,14 +6482,18 @@ static struct hda_verb alc885_mbp3_init_
{0x14, AC_VERB_SET_AMP_GAIN_MUTE, AMP_OUT_UNMUTE},
{0x14, AC_VERB_SET_CONNECT_SEL, 0x00},
- /* HP Pin: output 0 (0x0d) */
+ /* HP Pin: output 0 (0x0e) */
{0x15, AC_VERB_SET_PIN_WIDGET_CONTROL, 0xc4},
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Powered by JetHome